# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 0.3.39
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mainnet.configuration import Configuration


class SignedMessageResponseRaw(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'ecdsa': 'str',
        'schnorr': 'str',
        'der': 'str'
    }

    attribute_map = {
        'ecdsa': 'ecdsa',
        'schnorr': 'schnorr',
        'der': 'der'
    }

    def __init__(self, ecdsa=None, schnorr=None, der=None, local_vars_configuration=None):  # noqa: E501
        """SignedMessageResponseRaw - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._ecdsa = None
        self._schnorr = None
        self._der = None
        self.discriminator = None

        if ecdsa is not None:
            self.ecdsa = ecdsa
        if schnorr is not None:
            self.schnorr = schnorr
        if der is not None:
            self.der = der

    @property
    def ecdsa(self):
        """Gets the ecdsa of this SignedMessageResponseRaw.  # noqa: E501

        Elliptic Curve Digital messageHash encoded as a base64 string  # noqa: E501

        :return: The ecdsa of this SignedMessageResponseRaw.  # noqa: E501
        :rtype: str
        """
        return self._ecdsa

    @ecdsa.setter
    def ecdsa(self, ecdsa):
        """Sets the ecdsa of this SignedMessageResponseRaw.

        Elliptic Curve Digital messageHash encoded as a base64 string  # noqa: E501

        :param ecdsa: The ecdsa of this SignedMessageResponseRaw.  # noqa: E501
        :type ecdsa: str
        """

        self._ecdsa = ecdsa

    @property
    def schnorr(self):
        """Gets the schnorr of this SignedMessageResponseRaw.  # noqa: E501

        Schnorr signature of the messageHash encoded as a base64 string, Note from libauth: Nonces are generated using RFC6979, where the Section 3.6, 16-byte ASCII \"additional data\" is set to Schnorr+SHA256, see https://libauth.org/interfaces/secp256k1.html#signmessagehashschnorr   # noqa: E501

        :return: The schnorr of this SignedMessageResponseRaw.  # noqa: E501
        :rtype: str
        """
        return self._schnorr

    @schnorr.setter
    def schnorr(self, schnorr):
        """Sets the schnorr of this SignedMessageResponseRaw.

        Schnorr signature of the messageHash encoded as a base64 string, Note from libauth: Nonces are generated using RFC6979, where the Section 3.6, 16-byte ASCII \"additional data\" is set to Schnorr+SHA256, see https://libauth.org/interfaces/secp256k1.html#signmessagehashschnorr   # noqa: E501

        :param schnorr: The schnorr of this SignedMessageResponseRaw.  # noqa: E501
        :type schnorr: str
        """

        self._schnorr = schnorr

    @property
    def der(self):
        """Gets the der of this SignedMessageResponseRaw.  # noqa: E501

        Signature of messageHash using DER (Distinguished Encoding Rules)   # noqa: E501

        :return: The der of this SignedMessageResponseRaw.  # noqa: E501
        :rtype: str
        """
        return self._der

    @der.setter
    def der(self, der):
        """Sets the der of this SignedMessageResponseRaw.

        Signature of messageHash using DER (Distinguished Encoding Rules)   # noqa: E501

        :param der: The der of this SignedMessageResponseRaw.  # noqa: E501
        :type der: str
        """

        self._der = der

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SignedMessageResponseRaw):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SignedMessageResponseRaw):
            return True

        return self.to_dict() != other.to_dict()
